---
name: "🚀🆕 Feature Request"
about: "Suggest an idea or possible new feature for this project."
title: ""
labels: "Type: Feature"


---

# **🚀 Feature Request**

## **Is your feature request related to a problem? Please describe.**
<!-- A clear and concise description of what the problem is. Ex. I'm always frustrated when [...] -->

*

---

## **Describe the solution you'd like**
<!-- A clear and concise description of what you want to happen. -->

*

---

## **Describe alternatives you've considered**
<!-- A clear and concise description of any alternative solutions or features you've considered. -->

*

---

### **Additional context**
<!-- Add any other context or additional information about the problem here.-->

*

<!--📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛

Oh, hi there! 😄

To expedite issue processing, please search open and closed issues before submitting a new one.
Please read our Rules of Conduct at this repository's `.github/CODE_OF_CONDUCT.md`

📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛📛-->
